Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1654)

Unified Diff: android_webview/browser/aw_browser_permission_request_delegate.h

Issue 1158813002: Use RenderFrameHost for ::RequestPermission() and ::CancelPermission(). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: build fixes Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | android_webview/browser/aw_permission_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: android_webview/browser/aw_browser_permission_request_delegate.h
diff --git a/android_webview/browser/aw_browser_permission_request_delegate.h b/android_webview/browser/aw_browser_permission_request_delegate.h
index 501ea9005bbfc3ed0751ebc022116c2174c80367..7285af8f8088c82d9e6401efcee27f2cfb3e9f60 100644
--- a/android_webview/browser/aw_browser_permission_request_delegate.h
+++ b/android_webview/browser/aw_browser_permission_request_delegate.h
@@ -14,9 +14,9 @@ namespace android_webview {
class AwBrowserPermissionRequestDelegate {
public:
// Returns the AwBrowserPermissionRequestDelegate instance associated with
// the given render_process_id and render_view_id, or NULL.
static AwBrowserPermissionRequestDelegate* FromID(int render_process_id,
- int render_view_id);
+ int render_frame_id);
virtual void RequestProtectedMediaIdentifierPermission(
const GURL& origin,
« no previous file with comments | « no previous file | android_webview/browser/aw_permission_manager.h » ('j') | no next file with comments »
@@ -14,9 +14,9 @@ namespace android_webview {
public:
// Returns the AwBrowserPermissionRequestDelegate instance associated with
- // the given render_process_id and render_view_id, or NULL.
+ // the given render_process_id and render_frame_id, or NULL.
static AwBrowserPermissionRequestDelegate* FromID(int render_process_id,

Powered by Google App Engine
This is Rietveld 408576698